import whisper
from faster_whisper import WhisperModel

import config
from recognizer import RecognizerStrategy

class FastWhisperStrategy(RecognizerStrategy):
  def __init__(self) -> None:
      self._model = WhisperModel(
      model_size=config.HARPYIA_MODEL,
      device=config.DEVICE,
      num_workers=6,
      cpu_threads=10,
      # in_memory=True,
    )

  def recognize(self, file) -> str:
      audio = self._prepare_file(file.name)
      return self._transcribe(audio)

  def _prepare_file(self, filename: str):
    audio = whisper.load_audio(filename, sr=16000)
    audio = whisper.pad_or_trim(audio)
    return audio


  def _transcribe(self, audio):
    segments, _ = self._model.transcribe(
      audio,
      language=config.HARPYIA_LANGUAGE,
      initial_prompt=config.HARPYIA_PROMPT,
      condition_on_previous_text=False,
      vad_filter=True,
      beam_size=5,
    )

    return segments